@@ -4,7 +4,7 @@ from threading import RLock, Event
 from pyobs.mixins import FitsNamespaceMixin
 
 from pyobs.events import FilterChangedEvent, InitializedEvent, TelescopeMovingEvent
-from pyobs.interfaces import IFilters, IFitsHeaderProvider, IFocuser, ITemperatures, IAltAzMount, IMotion
+from pyobs.interfaces import IFilters, IFitsHeaderProvider, IFocuser, ITemperatures, IAltAzOffsets, IMotion
 from pyobs.modules import timeout
 from pyobs.modules.telescope.basetelescope import BaseTelescope
 from pyobs.utils.threads import LockWithAbort
@@ -13,7 +13,7 @@ from .pilardriver import PilarDriver
 log = logging.getLogger(__name__)
 
 
-class PilarTelescope(BaseTelescope, IAltAzMount, IFilters, IFitsHeaderProvider, IFocuser, ITemperatures,
+class PilarTelescope(BaseTelescope, IAltAzOffsets, IFilters, IFitsHeaderProvider, IFocuser, ITemperatures,
                      FitsNamespaceMixin):
     def __init__(self, host: str, port: int, username: str, password: str, pilar_fits_headers: dict = None,
                  temperatures: dict = None, force_filter_forward: bool = True, *args, **kwargs):
@@ -317,7 +317,7 @@ class PilarTelescope(BaseTelescope, IAltAzMount, IFilters, IFitsHeaderProvider,
         else:
             raise ValueError('Could not reach destination.')
 
-    def _track_radec(self, ra: float, dec: float, abort_event: Event):
+    def _move_radec(self, ra: float, dec: float, abort_event: Event):
         """Actually starts tracking on given coordinates. Must be implemented by derived classes.
 
         Args:
